package sun.text.normalizer;

import java.io.IOException;
import java.util.Arrays;
import java.io.DataInputStream;
import java.io.InputStream;

public final class ICUBinary
{
    private static final byte MAGIC1 = -38;
    private static final byte MAGIC2 = 39;
    private static final byte BIG_ENDIAN_ = 1;
    private static final byte CHAR_SET_ = 0;
    private static final byte CHAR_SIZE_ = 2;
    private static final String MAGIC_NUMBER_AUTHENTICATION_FAILED_ = "ICU data file error: Not an ICU data file";
    private static final String HEADER_AUTHENTICATION_FAILED_ = "ICU data file error: Header authentication failed, please check if you have a valid ICU data file";
    
    public ICUBinary() {
    }
    
    public static final byte[] readHeader(InputStream in, byte[] a, ICUBinary.Authenticate authenticate) throws IOException {
        DataInputStream dataInputStream = new DataInputStream(in);
        int char1 = dataInputStream.readChar();
        int n = '\u0002';
        int byte1 = dataInputStream.readByte();
        ++n;
        int byte2 = dataInputStream.readByte();
        ++n;
        if (byte1 != -38 || byte2 != 39) {
            throw new IOException("ICU data file error: Not an ICU data file");
        }
        dataInputStream.readChar();
        n += '\u0002';
        dataInputStream.readChar();
        n += '\u0002';
        int byte3 = dataInputStream.readByte();
        ++n;
        int byte4 = dataInputStream.readByte();
        ++n;
        int byte5 = dataInputStream.readByte();
        ++n;
        dataInputStream.readByte();
        ++n;
        byte[] array = new byte[4];
        dataInputStream.readFully(array);
        n += '\u0004';
        byte[] b = new byte[4];
        dataInputStream.readFully(b);
        n += '\u0004';
        byte[] b2 = new byte[4];
        dataInputStream.readFully(b2);
        n += '\u0004';
        if (char1 < n) {
            throw new IOException("Internal Error: Header size error");
        }
        dataInputStream.skipBytes(char1 - n);
        if (byte3 != 1 || byte4 != 0 || byte5 != 2 || !Arrays.equals(a, array) || (authenticate != null && !authenticate.isDataVersionAcceptable(b))) {
            throw new IOException("ICU data file error: Header authentication failed, please check if you have a valid ICU data file");
        }
        return b2;
    }
    
    public interface Authenticate
    {
        public abstract boolean isDataVersionAcceptable(byte[] p0);
    }
}
